List namespaces in catalog
GET /accounts/{account_id}/r2-catalog/{bucket_name}/namespaces
Returns a list of namespaces in the specified R2 catalog. Supports hierarchical filtering and pagination for efficient traversal of large namespace hierarchies.
Responses
200 List of namespaces retrieved successfully.
Data is at
body["result"]
{
"details": [
{
"created_at": "*string*",
"namespace": [
null
],
"namespace_uuid": "*string*",
"updated_at": "*string*"
}
],
"namespace_uuids": [
"*string*"
],
"namespaces": [
[
"*string*"
]
],
"next_page_token": "*string*"
}400 Bad request (e.g., invalid page_size, malformed parent namespace).
{
"errors": [
{
"code": "*integer*",
"message": "*string*"
}
],
"messages": [
{}
],
"success": "*boolean*"
}401 Authentication failed.
{
"errors": [
{
"code": "*integer*",
"message": "*string*"
}
],
"messages": [
{}
],
"success": "*boolean*"
}403 Forbidden.
{
"errors": [
{
"code": "*integer*",
"message": "*string*"
}
],
"messages": [
{}
],
"success": "*boolean*"
}404 Catalog not found.
{
"errors": [
{
"code": "*integer*",
"message": "*string*"
}
],
"messages": [
{}
],
"success": "*boolean*"
}500 Internal server error.
{
"errors": [
{
"code": "*integer*",
"message": "*string*"
}
],
"messages": [
{}
],
"success": "*boolean*"
}