Get HTTP authentication requests by bot class summary
GET /radar/leaked_credential_checks/summary/bot_class
Retrieves the distribution of HTTP authentication requests by bot class.
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"summary_0": {
"bot": "*string*",
"human": "*string*"
}
}400 Bad request.
{
"errors": [
{
"message": "*string*"
}
],
"result": {},
"success": "*boolean*"
}Get HTTP authentication requests by compromised credential status summary
GET /radar/leaked_credential_checks/summary/compromised
Retrieves the distribution of HTTP authentication requests by compromised credential status.
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"summary_0": {
"CLEAN": "*string*",
"COMPROMISED": "*string*"
}
}400 Bad request.
{
"errors": [
{
"message": "*string*"
}
],
"result": {},
"success": "*boolean*"
}Get HTTP authentication requests distribution by dimension
GET /radar/leaked_credential_checks/summary/{dimension}
Retrieves an aggregated summary of HTTP authentication requests grouped by the specified dimension.
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"summary_0": {}
}400 Bad request.
{
"errors": [
{
"message": "*string*"
}
],
"result": {},
"success": "*boolean*"
}Get HTTP authentication requests by bot class time series
GET /radar/leaked_credential_checks/timeseries_groups/bot_class
Retrieves the distribution of HTTP authentication requests by bot class over time.
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"aggInterval": "*string*",
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"serie_0": {
"bot": [
"*string*"
],
"human": [
"*string*"
],
"timestamps": [
"*string*"
]
}
}400 Bad request.
{
"errors": [
{
"message": "*string*"
}
],
"result": {},
"success": "*boolean*"
}Get HTTP authentication requests by compromised credential status time series
GET /radar/leaked_credential_checks/timeseries_groups/compromised
Retrieves the distribution of HTTP authentication requests by compromised credential status over time.
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"aggInterval": "*string*",
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"serie_0": {
"CLEAN": [
"*string*"
],
"COMPROMISED": [
"*string*"
],
"timestamps": [
"*string*"
]
}
}400 Bad request.
{
"errors": [
{
"message": "*string*"
}
],
"result": {},
"success": "*boolean*"
}Get time series distribution of HTTP authentication requests by dimension.
GET /radar/leaked_credential_checks/timeseries_groups/{dimension}
Retrieves the distribution of HTTP authentication requests, grouped by the specified dimension over time.
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"aggInterval": "*string*",
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"serie_0": {
"timestamps": [
"*string*"
]
}
}400 Bad request.
{
"errors": [
{
"message": "*string*"
}
],
"result": {},
"success": "*boolean*"
}