Create a meeting
POST /accounts/{account_id}/realtime/kit/{app_id}/meetings
Create a meeting for the given App ID.
Responses
201
Data is at
body["result"]
Fetch all meetings for an App
GET /accounts/{account_id}/realtime/kit/{app_id}/meetings
Returns all meetings for the given App ID.
Responses
200
Data is at
body["result"]
Replace a meeting
PUT /accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}
Replaces all the details for the given meeting ID.
Responses
200
Data is at
body["result"]
Update a meeting
PATCH /accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}
Updates a meeting in an App for the given meeting ID.
Responses
200
Data is at
body["result"]
500
Fetch a meeting for an App
GET /accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}
Returns a meeting details in an App for the given meeting ID.
Responses
200
Data is at
body["result"]
500
Add a participant
POST /accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/participants
Adds a participant to the given meeting ID.
Responses
201
Data is at
body["result"]
500
Fetch all participants of a meeting
GET /accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/participants
Returns all participants detail for the given meeting ID.
Responses
200
Data is at
body["result"]
500
Edit a participant's detail
PATCH /accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/participants/{participant_id}
Updates a participant's details for the given meeting and participant ID.
Responses
200
Data is at
body["result"]
500
Fetch a participant's detail
GET /accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/participants/{participant_id}
Returns a participant details for the given meeting and participant ID.
Responses
200
Data is at
body["result"]
500
Delete a participant
DELETE /accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/participants/{participant_id}
Deletes a participant for the given meeting and participant ID.
Responses
200
Data is at
body["result"]
500
Refresh participant's authentication token
POST /accounts/{account_id}/realtime/kit/{app_id}/meetings/{meeting_id}/participants/{participant_id}/token
Regenerates participant's authentication token for the given meeting and participant ID.
Responses
200
Data is at
body["result"]
500