Get network traffic summary
GET /radar/netflows/summary
Retrieves the distribution of network traffic (NetFlows) by HTTP vs other protocols.
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"summary_0": {
"HTTP": "*string*",
"OTHER": "*string*"
}
}400 Bad request.
{
"errors": [
{
"message": "*string*"
}
],
"result": {},
"success": "*boolean*"
}Get network traffic distribution by dimension
GET /radar/netflows/summary/{dimension}
Retrieves the distribution of network traffic (NetFlows) by the specified dimension.
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"summary_0": {}
}400 Bad request.
{
"errors": [
{
"message": "*string*"
}
],
"result": {},
"success": "*boolean*"
}Get network traffic time series
GET /radar/netflows/timeseries
Retrieves network traffic (NetFlows) over time.
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"aggInterval": "*string*",
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"serie_0": {
"timestamps": [
"*string*"
],
"values": [
"*string*"
]
}
}400 Bad request.
{
"errors": [
{
"message": "*string*"
}
],
"result": {},
"success": "*boolean*"
}Get time series distribution of network traffic by dimension
GET /radar/netflows/timeseries_groups/{dimension}
Retrieves the distribution of NetFlows traffic, grouped by the specified dimension over time.
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"aggInterval": "*string*",
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"serie_0": {
"timestamps": [
"*string*"
]
}
}400 Bad request.
{
"errors": [
{
"message": "*string*"
}
],
"result": {},
"success": "*boolean*"
}Get top ASes by network traffic
GET /radar/netflows/top/ases
Retrieves the top autonomous systems by network traffic (NetFlows).
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"top_0": [
{
"clientASN": "*number*",
"clientASName": "*string*",
"value": "*string*"
}
]
}404 Not found.
{
"error": "*string*"
}Get top locations by network traffic
GET /radar/netflows/top/locations
Retrieves the top locations by network traffic (NetFlows).
Responses
200 Successful response.
Data is at
body["result"]
{
"meta": {
"confidenceInfo": {
"annotations": [
{
"dataSource": "*string*",
"description": "*string*",
"endDate": "*string*",
"eventType": "*string*",
"isInstantaneous": "*boolean*",
"linkedUrl": "*string*",
"startDate": "*string*"
}
],
"level": "*integer*"
},
"dateRange": [
{
"endTime": "*string*",
"startTime": "*string*"
}
],
"lastUpdated": "*string*",
"normalization": "*string*",
"units": [
{
"name": "*string*",
"value": "*string*"
}
]
},
"top_0": [
{
"clientCountryAlpha2": "*string*",
"clientCountryName": "*string*",
"value": "*string*"
}
]
}404 Not found.
{
"error": "*string*"
}